==> owncloud-8.1.0p2.tgz: owncloud/lib/l10n/ar.js <==
OC.L10N.register(
    "lib",
    {
    "Help" : "المساعدة",
    "Personal" : "شخصي",
    "Users" : "المستخدمين",
    "Admin" : "المدير",
    "No app name specified" : "لا يوجد برنامج بهذا الاسم",
    "Unknown filetype" : "نوع الملف غير معروف",
    "Invalid image" : "الصورة غير صالحة",
    "today" : "اليوم",
    "yesterday" : "يوم أمس",
    "last month" : "الشهر الماضي",
    "last year" : "السنةالماضية",
    "seconds ago" : "منذ ثواني",
    "web services under your control" : "خدمات الشبكة تحت سيطرتك",
    "App directory already exists" : "مجلد التطبيق موجود مسبقا",
    "Can't create app folder. Please fix permissions. %s" : "لا يمكن إنشاء مجلد التطبيق. يرجى تعديل الصلاحيات. %s",
    "No source specified when installing app" : "لم يتم تحديد المصدر عن تثبيت البرنامج",
    "Archives of type %s are not supported" : "الأرشيفات من نوع  %s غير مدعومة",
    "App does not provide an info.xml file" : "التطبيق لا يتوفر على ملف info.xml",
    "Application is not enabled" : "التطبيق غير مفعّل",
    "Authentication error" : "لم يتم التأكد من الشخصية بنجاح",
    "Token expired. Please reload page." : "انتهت صلاحية الكلمة , يرجى اعادة تحميل الصفحة",
    "Unknown user" : "المستخدم غير معروف",
    "%s enter the database username." : "%s ادخل اسم المستخدم الخاص بقاعدة البيانات.",
    "%s enter the database name." : "%s ادخل اسم فاعدة البيانات",
    "%s you may not use dots in the database name" : "%s لا يسمح لك باستخدام نقطه (.) في اسم قاعدة البيانات",
    "MS SQL username and/or password not valid: %s" : "اسم المستخدم  و/أو  كلمة المرور لنظام MS SQL غير صحيح : %s",
    "You need to enter either an existing account or the administrator." : "انت بحاجة لكتابة اسم مستخدم موجود أو حساب المدير.",
    "MySQL/MariaDB username and/or password not valid" : "اسم مستخدم أو كلمة مرور MySQL/MariaDB  غير صحيحين",
    "DB Error: \"%s\"" : "خطأ في قواعد البيانات : \"%s\"",
    "Offending command was: \"%s\"" : "الأمر المخالف كان : \"%s\"",
    "MySQL/MariaDB user '%s'@'localhost' exists already." : "مستخدم MySQL/MariaDB '%s'@'localhost' موجود مسبقا",
    "Drop this user from MySQL/MariaDB." : "حذف هذا المستخدم من MySQL/MariaDB",
    "Oracle connection could not be established" : "لم تنجح محاولة اتصال Oracle",
    "Oracle username and/or password not valid" : "اسم المستخدم  و/أو  كلمة المرور لنظام Oracle غير صحيح",
    "Offending command was: \"%s\", name: %s, password: %s" : "الأمر المخالف كان : \"%s\", اسم المستخدم : %s, كلمة المرور: %s",
    "PostgreSQL username and/or password not valid" : "اسم المستخدم / أو كلمة المرور الخاصة بـPostgreSQL غير صحيحة",
    "Set an admin username." : "اعداد اسم مستخدم للمدير",
    "Set an admin password." : "اعداد كلمة مرور للمدير",
    "%s shared »%s« with you" : "%s شارك »%s« معك",
    "Could not find category \"%s\"" : "تعذر العثور على المجلد \"%s\"",
    "A valid username must be provided" : "يجب ادخال اسم مستخدم صحيح",
    "A valid password must be provided" : "يجب ادخال كلمة مرور صحيحة"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> owncloud-9.0.3.tgz: owncloud/lib/l10n/ar.js <==
OC.L10N.register(
    "lib",
    {
    "Help" : "المساعدة",
    "Personal" : "شخصي",
    "Users" : "المستخدمين",
    "Admin" : "المدير",
    "No app name specified" : "لا يوجد برنامج بهذا الاسم",
    "Unknown filetype" : "نوع الملف غير معروف",
    "Invalid image" : "الصورة غير صالحة",
    "today" : "اليوم",
    "yesterday" : "يوم أمس",
    "last month" : "الشهر الماضي",
    "last year" : "السنةالماضية",
    "seconds ago" : "منذ ثواني",
    "web services under your control" : "خدمات الشبكة تحت سيطرتك",
    "App directory already exists" : "مجلد التطبيق موجود مسبقا",
    "Can't create app folder. Please fix permissions. %s" : "لا يمكن إنشاء مجلد التطبيق. يرجى تعديل الصلاحيات. %s",
    "No source specified when installing app" : "لم يتم تحديد المصدر عن تثبيت البرنامج",
    "Archives of type %s are not supported" : "الأرشيفات من نوع  %s غير مدعومة",
    "App does not provide an info.xml file" : "التطبيق لا يتوفر على ملف info.xml",
    "Application is not enabled" : "التطبيق غير مفعّل",
    "Authentication error" : "لم يتم التأكد من الشخصية بنجاح",
    "Token expired. Please reload page." : "انتهت صلاحية الكلمة , يرجى اعادة تحميل الصفحة",
    "Unknown user" : "المستخدم غير معروف",
    "%s enter the database username." : "%s ادخل اسم المستخدم الخاص بقاعدة البيانات.",
    "%s enter the database name." : "%s ادخل اسم فاعدة البيانات",
    "%s you may not use dots in the database name" : "%s لا يسمح لك باستخدام نقطه (.) في اسم قاعدة البيانات",
    "Oracle connection could not be established" : "لم تنجح محاولة اتصال Oracle",
    "Oracle username and/or password not valid" : "اسم المستخدم  و/أو  كلمة المرور لنظام Oracle غير صحيح",
    "DB Error: \"%s\"" : "خطأ في قواعد البيانات : \"%s\"",
    "Offending command was: \"%s\"" : "الأمر المخالف كان : \"%s\"",
    "You need to enter either an existing account or the administrator." : "انت بحاجة لكتابة اسم مستخدم موجود أو حساب المدير.",
    "Offending command was: \"%s\", name: %s, password: %s" : "الأمر المخالف كان : \"%s\", اسم المستخدم : %s, كلمة المرور: %s",
    "PostgreSQL username and/or password not valid" : "اسم المستخدم / أو كلمة المرور الخاصة بـPostgreSQL غير صحيحة",
    "Set an admin username." : "اعداد اسم مستخدم للمدير",
    "Set an admin password." : "اعداد كلمة مرور للمدير",
    "%s shared »%s« with you" : "%s شارك »%s« معك",
    "Could not find category \"%s\"" : "تعذر العثور على المجلد \"%s\"",
    "Apps" : "التطبيقات",
    "A valid username must be provided" : "يجب ادخال اسم مستخدم صحيح",
    "A valid password must be provided" : "يجب ادخال كلمة مرور صحيحة",
    "Storage not available" : "وحدة التخزين غير متوفرة "
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
